/*********************************************************************
 * Sequence for Desktop Station main
 *
 * Copyright (C) 2015 Yaasan
 *
 */

#include <Arduino.h>
#include <EEPROM.h>
#include "DSCoreM_Type.h"
#include "DSCoreM_Common.h"
#include "DSCoreM.h"
#include "DSSequence.h"

#define PIN_SW_DIR A1	//
#define PIN_VR A2		//
#define PORT_BTNA	A7


DSSequence::DSSequence()
{

}

void DSSequence::Init()
{
	gButtonStatus = getButtonStatus();
}



byte DSSequence::getButtonStatus()
{
	word aButton_val = 0;
	
	byte aTempBtnA = 0;
	
	word aButtonA = analogRead(PORT_BTNA);
	
	//Get button status
	aTempBtnA = GetButtonsFromAD(aButtonA);
	
	//Check and process the buttons
	aButton_val = ProcessCheck(aTempBtnA);
	
	return aButton_val;
}

word DSSequence::getDialStatus()
{
	word aData = analogRead(PIN_VR);
	aData = (aData & 0b1111111000);
	
	if( aData > 1023)
	{
		aData = 1023;
	}
	
	//Mask lower 3bits (1024 to 256)
	return aData;
}


bool DSSequence::Interval()
{
	bool aChange = false;
	word aButton_val = 0;
	
	//Input Buttons
	aButton_val = getButtonStatus();
	
	//ボタンのチェック
	if( aButton_val != gButtonStatus)
	{
		aChange = true;
		
		gButtonStatus = aButton_val;
		
	}
	else
	{
		//Nothing to do
	}	
	
	return aChange;
	
}	




word DSSequence::ProcessCheck( word inTemp)
{
	byte aChanged = 0;
	word aButtonData = 0;

// PCB Revision 4
	switch(inTemp)
	{
	case 1:
		//ENTER
		bitWrite(aButtonData, 1, 1);
		break;
	case 2:
		//UP
		bitWrite(aButtonData, 3, 1);
		break;
	case 4:
		//DOWN
		bitWrite(aButtonData, 4, 1);
		break;
	case 8:
		//ESC
		bitWrite(aButtonData, 2, 1);
		break;
	case 16:
		//RUN/STOP
		bitWrite(aButtonData, 6, 1);
		break;
	}

	return aButtonData;
	
}


byte DSSequence::GetButtonsFromAD(unsigned short inADData)
{
	/*
	R1	2.2kΩ
	R2	470Ω
	R3	1kΩ
	R4	2.2kΩ
	R5	6.8kΩ
	
	Threshold value:
	SW1: 82
	SW2: 290
	SW3: 525
	SW4: 747
	SW5: 942
	
	
	*/
	
	byte aRet = 0;
	
	if( inADData <= 82)
	{
		aRet = 1 << 0;
	}
	else if( inADData <= 290)
	{
		aRet = 1 << 1;
	}
	else if( inADData <= 525)
	{
		aRet = 1 << 2;
	}
	else if( inADData <= 747)
	{
		aRet = 1 << 3;
	}
	else if( inADData <= 942)
	{
		aRet = 1 << 4;
	}
	else
	{
		//Not pressed
	}
	
	
	return aRet;
}
